@@ -1,5 +1,7 @@
 # If we do not have a loaded session, load or create one
 if {![info exists ::session::vars(sessionid)]} {
+	debug::log "sessions.tcl" "No session is currently loaded"
+
 	# Get the session ID from a cookie
 	set sessionid [cookie get sessionid]
 
@@ -13,10 +15,14 @@ if {![info exists ::session::vars(sessionid)]} {
 		# Create a new session
 		set sessionid [session::create]
 
+		debug::log "sessions.tcl" "No session found, creating a new one: $sessionid"
+
 		# Set a cookie to hold the session ID
 		cookie set sessionid $sessionid -minutes 720
 	} else {
 		# Load the session
+		debug::log "sessions.tcl" "Found session ID: $sessionid, loading it"
+
 		session::load $sessionid
 	}
 
